@@ -242,6 +242,7 @@ int set_default_options(mod_gm_opt_t *opt) {
     opt->perfdata_mode      = GM_PERFDATA_OVERWRITE;
     opt->perfdata_send_all  = GM_DISABLED;
     opt->use_uniq_jobs      = GM_ENABLED;
+    opt->log_stats_interval = 60;
     opt->do_hostchecks      = GM_ENABLED;
     opt->route_eventhandler_like_checks = GM_DISABLED;
     opt->hosts              = GM_DISABLED;
@@ -317,7 +318,7 @@ int set_default_options(mod_gm_opt_t *opt) {
     }
     opt->exports_count = 0;
     opt->restrict_path_num      = 0;
-    opt->gearman_connection_timeout = -1;
+    opt->gearman_connection_timeout = 5000;
     for(i=0;i<GM_LISTSIZE;i++)
         opt->restrict_path[i] = NULL;
 
@@ -595,6 +596,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         }
     }
 
+    /* log_stats_interval  */
+    else if ( !strcmp( key, "log_stats_interval" ) ) {
+        opt->log_stats_interval = atoi( value );
+        if(opt->log_stats_interval < 0) { opt->log_stats_interval = 0; }
+    }
+
     /* result worker */
     else if ( !strcmp( key, "result_workers" ) ) {
         opt->result_workers = atoi( value );
@@ -1018,6 +1025,8 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
         gm_log( GM_LOG_DEBUG, "log mode:                        syslog (%d)\n", opt->logmode);
     if(opt->logmode == GM_LOG_MODE_TOOLS)
         gm_log( GM_LOG_DEBUG, "log mode:                        tools (%d)\n", opt->logmode);
+    if(opt->logmode == GM_LOG_MODE_CHECKS)
+        gm_log( GM_LOG_DEBUG, "log mode:            monitoring plugin (%d)\n", opt->logmode);
 
     if(mode == GM_WORKER_MODE) {
         gm_log( GM_LOG_DEBUG, "identifier:                      %s\n", opt->identifier);
@@ -1243,7 +1252,6 @@ int set_default_job(gm_job_t *job, mod_gm_opt_t *opt) {
     job->error               = NULL;
     job->exited_ok           = TRUE;
     job->scheduled_check     = TRUE;
-    job->reschedule_check    = TRUE;
     job->return_code         = STATE_OK;
     job->latency             = 0.0;
     job->timeout             = opt->job_timeout;
@@ -1479,6 +1487,11 @@ void gm_log( int lvl, const char *text, ... ) {
     vsnprintf( buffer3, GM_BUFFERSIZE, text, ap );
     va_end( ap );
 
+    if ( debug_level >= GM_LOG_STDOUT || logmode == GM_LOG_MODE_CHECKS ) {
+        fprintf(stderr, "%s", buffer3 );
+        return;
+    }
+
     if ( debug_level >= GM_LOG_STDOUT || logmode == GM_LOG_MODE_TOOLS ) {
         printf( "%s", buffer3 );
         return;
@@ -1601,7 +1614,9 @@ void send_result_back(gm_job_t * exec_job) {
                          temp_buffer1,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode
+                         mod_gm_opt->transportmode,
+                         0,
+                         0
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "send_result_back() finished successfully\n" );
     }
@@ -1623,7 +1638,9 @@ void send_result_back(gm_job_t * exec_job) {
                               temp_buffer2,
                               GM_JOB_PRIO_NORMAL,
                               GM_DEFAULT_JOB_RETRIES,
-                              mod_gm_opt->transportmode
+                              mod_gm_opt->transportmode,
+                              0,
+                              0
                             ) == GM_OK) {
             gm_log( GM_LOG_TRACE, "send_result_back() finished successfully for duplicate server.\n" );
         }
@@ -1754,3 +1771,10 @@ void make_uniq(char *uniq, const char *format, ... ) {
     snprintf(uniq, GM_SMALLBUFSIZE, "%s", md5);
     gm_free(md5);
 }
+
+double elapsed_time(struct timeval t1, struct timeval t2) {
+    long seconds = t2.tv_sec - t1.tv_sec;
+    long microseconds = t2.tv_usec - t1.tv_usec;
+    double elapsed = seconds + microseconds*1e-6;
+    return(elapsed);
+}
\ No newline at end of file
