@@ -260,7 +260,7 @@ int nebmodule_deinit( int flags, int reason ) {
     }
 
     /* cleanup */
-    free_client(&client);
+    gm_free_client(&client);
 
     /* close old logfile */
     if(mod_gm_opt->logfile_fp != NULL) {
@@ -471,7 +471,9 @@ static int handle_eventhandler( int event_type, void *data ) {
                          temp_buffer,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode
+                         mod_gm_opt->transportmode,
+                         1,
+                         mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "handle_eventhandler() finished successfully\n" );
     }
@@ -672,7 +674,9 @@ static int handle_notifications( int event_type, void *data ) {
                          temp_buffer,
                          GM_JOB_PRIO_HIGH,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode
+                         mod_gm_opt->transportmode,
+                         1,
+                         mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "handle_notifications() finished successfully\n" );
     }
@@ -790,8 +794,6 @@ static int handle_host_check( int event_type, void *data ) {
 #endif
     int check_options;
     struct timeval core_time;
-    struct tm next_check;
-    char buffer1[GM_BUFFERSIZE];
 
     gettimeofday(&core_time,NULL);
 
@@ -826,7 +828,10 @@ static int handle_host_check( int event_type, void *data ) {
         return NEB_OK;
     }
 
-    gm_log( GM_LOG_DEBUG, "received job for queue %s: %s, check_options: %d\n", target_queue, hostdata->host_name, check_options );
+    if(hostdata->latency < 0)
+        hostdata->latency = 0;
+
+    gm_log(GM_LOG_DEBUG, "received job for queue %s: %s, check_options: %d    latency so far: %.3fs\n", target_queue, hostdata->host_name, check_options, hostdata->latency);
 
     /* as we have to intercept host checks so early
      * (we cannot cancel checks otherwise)
@@ -847,26 +852,17 @@ static int handle_host_check( int event_type, void *data ) {
         return NEBERROR_CALLBACKCANCEL;
     }
 
-    /* log latency */
-    if(mod_gm_opt->debug_level >= GM_LOG_DEBUG) {
-        localtime_r(&hst->next_check, &next_check);
-        strftime(buffer1, sizeof(buffer1), "%Y-%m-%d %H:%M:%S", &next_check );
-        gm_log( GM_LOG_DEBUG, "host: '%s', next_check is at %s, latency so far: %i\n", hst->name, buffer1, ((int)core_time.tv_sec - (int)hst->next_check));
-    }
-
     /* set the execution flag */
     hst->is_executing=TRUE;
 
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
     temp_buffer[0]='\x0';
-    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=host\nresult_queue=%s\nhost_name=%s\nstart_time=%ld.0\nnext_check=%ld.0\ntimeout=%d\ncore_time=%Lf\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=host\nresult_queue=%s\nhost_name=%s\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               hst->name,
-              hst->next_check,
-              hst->next_check,
+              timeval2double(&core_time) - hostdata->latency, // can only assume planned start date since next_check already advanced to next check and last_check still points to previous check
               host_check_timeout,
-              timeval2double(&core_time),
               processed_command
             );
 
@@ -880,7 +876,9 @@ static int handle_host_check( int event_type, void *data ) {
                          temp_buffer,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode
+                         mod_gm_opt->transportmode,
+                         1,
+                         mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
     }
     else {
@@ -941,8 +939,6 @@ static int handle_svc_check( int event_type, void *data ) {
 #endif
     int check_options;
     struct timeval core_time;
-    struct tm next_check;
-    char buffer1[GM_BUFFERSIZE];
 
     gettimeofday(&core_time,NULL);
 
@@ -977,7 +973,10 @@ static int handle_svc_check( int event_type, void *data ) {
         return NEB_OK;
     }
 
-    gm_log( GM_LOG_DEBUG, "received job for queue %s: %s - %s, check_options: %d\n", target_queue, svcdata->host_name, svcdata->service_description, check_options );
+    if(svcdata->latency < 0)
+        svcdata->latency = 0;
+
+    gm_log(GM_LOG_DEBUG, "received job for queue %s: %s - %s, check_options: %d   latency so far: %.3fs\n", target_queue, svcdata->host_name, svcdata->service_description, check_options, svcdata->latency);
 
     /* as we have to intercept service checks so early
      * (we cannot cancel checks otherwise)
@@ -997,26 +996,17 @@ static int handle_svc_check( int event_type, void *data ) {
         return NEBERROR_CALLBACKCANCEL;
     }
 
-    /* log latency */
-    if(mod_gm_opt->debug_level >= GM_LOG_DEBUG) {
-        localtime_r(&svc->next_check, &next_check);
-        strftime(buffer1, sizeof(buffer1), "%Y-%m-%d %H:%M:%S", &next_check );
-        gm_log( GM_LOG_DEBUG, "service: '%s' - '%s', next_check is at %s, latency so far: %i\n", svcdata->host_name, svcdata->service_description, buffer1, ((int)core_time.tv_sec - (int)svc->next_check));
-    }
-
     /* set the execution flag */
     svc->is_executing=TRUE;
 
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
     temp_buffer[0]='\x0';
-    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\nstart_time=%ld.0\nnext_check=%ld.0\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               svcdata->host_name,
               svcdata->service_description,
-              svc->next_check,
-              svc->next_check,
-              timeval2double(&core_time),
+              timeval2double(&core_time) - svcdata->latency, // can only assume planned start date since next_check already advanced to next check and last_check still points to previous check
               service_check_timeout,
               processed_command
             );
@@ -1035,7 +1025,9 @@ static int handle_svc_check( int event_type, void *data ) {
                          temp_buffer,
                          prio,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode
+                         mod_gm_opt->transportmode,
+                         1,
+                         mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "handle_svc_check() finished successfully\n" );
     }
@@ -1391,7 +1383,9 @@ int handle_perfdata(int event_type, void *data) {
                                  temp_buffer,
                                  GM_JOB_PRIO_NORMAL,
                                  GM_DEFAULT_JOB_RETRIES,
-                                 mod_gm_opt->transportmode
+                                 mod_gm_opt->transportmode,
+                                 1,
+                                 mod_gm_opt->log_stats_interval
                                 ) == GM_OK) {
                 gm_log( GM_LOG_TRACE, "handle_perfdata() successfully added data to %s\n", perfdata_queue );
             }
@@ -1530,7 +1524,9 @@ int handle_export(int callback_type, void *data) {
                               temp_buffer,
                               GM_JOB_PRIO_NORMAL,
                               GM_DEFAULT_JOB_RETRIES,
-                              mod_gm_opt->transportmode
+                              mod_gm_opt->transportmode,
+                              1,
+                              mod_gm_opt->log_stats_interval
                             );
         }
     }
