@@ -81,7 +81,7 @@ void worker_client(int worker_mode, int indx, int shid) {
     }
 
     /* create client */
-    if ( create_client( mod_gm_opt->server_list, &client ) != GM_OK ) {
+    if ( create_client_blocking( mod_gm_opt->server_list, &client ) != GM_OK ) {
         gm_log( GM_LOG_ERROR, "cannot start client\n" );
         clean_worker_exit(0);
         _exit( EXIT_FAILURE );
@@ -90,7 +90,7 @@ void worker_client(int worker_mode, int indx, int shid) {
 
     /* create duplicate client */
     if( mod_gm_opt->dupserver_num ) {
-        if ( create_client( mod_gm_opt->dupserver_list, &client_dup ) != GM_OK ) {
+        if ( create_client_blocking( mod_gm_opt->dupserver_list, &client_dup ) != GM_OK ) {
             gm_log( GM_LOG_ERROR, "cannot start client for duplicate server\n" );
             _exit( EXIT_FAILURE );
         }
@@ -121,7 +121,6 @@ void worker_loop() {
             alarm(mod_gm_opt->idle_timeout);
         }
 
-        signal(SIGPIPE, SIG_IGN);
         ret = gearman_worker_work( &worker );
 
         if (mod_gm_opt->max_jobs > 0 && jobs_done >= mod_gm_opt->max_jobs) {
@@ -132,11 +131,10 @@ void worker_loop() {
 
         if ( ret != GEARMAN_SUCCESS ) {
             gm_log( GM_LOG_ERROR, "worker error: %s\n", gearman_worker_error( &worker ) );
-            gearman_job_free_all( &worker );
-            gearman_worker_free( &worker );
-            gearman_client_free( &client );
+            gm_free_worker(&worker);
+            gm_free_client( &client );
             if( mod_gm_opt->dupserver_num )
-                gearman_client_free( &client_dup );
+                gm_free_client( &client_dup );
 
             /* sleep on error to avoid cpu intensive infinite loops */
             sleep(sleep_time_after_error);
@@ -146,10 +144,10 @@ void worker_loop() {
 
             /* create new connections */
             set_worker( &worker );
-            create_client( mod_gm_opt->server_list, &client );
+            create_client_blocking( mod_gm_opt->server_list, &client );
             current_client = &client;
             if( mod_gm_opt->dupserver_num ) {
-                create_client( mod_gm_opt->dupserver_list, &client_dup );
+                create_client_blocking( mod_gm_opt->dupserver_list, &client_dup );
                 current_client_dup = &client_dup;
             }
         }
@@ -254,9 +252,6 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
         } else if ( !strcmp( key, "scheduled_check" ) ) {
             exec_job->scheduled_check = atoi(value);
             valid_lines++;
-        } else if ( !strcmp( key, "reschedule_check" ) ) {
-            exec_job->reschedule_check = atoi(value);
-            valid_lines++;
         } else if ( !strcmp( key, "latency" ) ) {
             exec_job->latency = atof(value);
             valid_lines++;
@@ -585,10 +580,9 @@ void clean_worker_exit(int sig) {
     }
 
     gm_log( GM_LOG_TRACE, "cleaning worker\n");
-    gearman_worker_unregister_all(&worker);
-    gearman_job_free_all( &worker );
+    gm_free_worker(&worker);
     gm_log( GM_LOG_TRACE, "cleaning client\n");
-    gearman_client_free( &client );
+    gm_free_client(&client);
     mod_gm_free_opt(mod_gm_opt);
 
 #ifdef EMBEDDEDPERL
